@@ -5,7 +5,7 @@ import logging
 import threading
 
 from wsgiref.simple_server import make_server, WSGIRequestHandler
-from .. import Request, Adapter, __version__
+from .. import Request, Adapter, User, __version__
 from ..utils import force_str
 from cgi import parse_qs
 
@@ -17,6 +17,8 @@ class HttpRequest(Request):
         self.response_sent = False
         self.method = environ['REQUEST_METHOD']
 
+        self.GET = parse_qs(environ['QUERY_STRING'])
+
         if self.method == 'POST':
             content_length = int(environ.get('CONTENT_LENGTH', 0))
             request_body = environ['wsgi.input'].read(content_length)
@@ -39,17 +41,10 @@ class HttpRequest(Request):
         self.response_sent = True
 
 
-class IRCConnection(irc.IRCConnection):
-    def get_logger(self, logger_name, filename):
-        """We override this method because don't want to have a separate log for irc messages.
-        """
-        return logging.getLogger(logger_name)
-
-
 class Adapter(Adapter):
     @staticmethod
     def get_options(parser):
-        group = parser.add_argument_group('IRC options')
+        group = parser.add_argument_group('HTTP options')
         group.add_argument(
             '--http-host', default='127.0.0.1',
             help='IP to bind to. Default: 127.0.0.1.'
